@@ -10,22 +10,25 @@ from python_easy_json import JSONObject
 
 
 class TestEnum(Enum):
-
     FirstValue = 1
     SecondValue = 2
 
 
 class TestIntEnum(IntEnum):
-
     FirstValue = 1
     SecondValue = 2
 
 
+class TestUnderscoreEnum(Enum):
+    data_with_hyphen = 1
+
+
 class ObjectWithEnum(JSONObject):
     """ JSONObject object class with Enum types """
     timestamp: datetime = None
     test_enum: TestEnum = None
     test_int_enum: TestIntEnum = None
+    underscore_enum: TestUnderscoreEnum = None
 
 
 class TestJSONWithEnum(BaseTestCase):
@@ -53,3 +56,17 @@ class TestJSONWithEnum(BaseTestCase):
         # TestIntEnum
         self.assertIsInstance(obj.test_int_enum, TestIntEnum)
         self.assertEqual(obj.test_int_enum, TestIntEnum.SecondValue)
+
+    def test_enum_with_hyphen_key(self):
+        """
+        Test case where the data value for an enum value has a hyphen in it.
+        """
+        data = {
+            'underscore_enum': 'data-with-hyphen'
+        }
+
+        obj = ObjectWithEnum(data, cast_types=True)
+
+        self.assertIsInstance(obj, JSONObject)
+
+        self.assertEqual(obj.underscore_enum, TestUnderscoreEnum.data_with_hyphen)
